Publications
============

If you find parakeet useful for you work, please consider citing our paper:

  Parkhurst, J. M., Dumoux, M., Basham, M., Clare, D., Siebert, C. A., Varslot,
  T., Kirkland, A., Naismith, J. H., & Evans, G. (2021). Parakeet: A digital
  twin software pipeline to assess the impact of experimental parameters on
  tomographic reconstructions for cryo-electron tomography. Open Biology,
  11(10). https://doi.org/10.1098/rsob.210160
